****************************************************************************
****   MODULE 1 - THEME 2 - ANALYZING TARIFF PROFILES  - APPLICATION 1  **** 
****************************************************************************

* The selected country is CANADA for 2008. 

* Data source: Bound Concessions, Tariff and Trade details available at http://tao.wto.org
* Remark: the commands can be applied to data sourced from wits.worldbank.org/witsweb with 
* slight modifications


* Data used: 	DutyDetails.txt;  
*			HS96Complete.dta; ProdGrp_hs96at6dig.dta;
*			ProdGrp_hs07at6dig.dta;
* 
* Data save:	DutyDetails.dta; 
*			TradeDetails.dta; 
*			TariffDetails.dta; 
*			Bounds.dta;


********* PRELIMINARY STEP *********
* Set memory and path 
		clear all
	set mem 300m
	set matsize 800
	graph drop _all
	

	cd "$input/Chapter2/Datasets"

********* IMPORT DATABASE *********

* Import the files from TAO/IDB (txt files) into Stata 
* If the data is imported from excel, the different worksheets have to be saved in 
* separate worksheets and saved as .txt or .csv files.
* Note that for Bound Data there might be observations that are shifted
* to the next line. A do-file correcting the problem is made available with this 
* handbook.

	* Import the MFN applied and bound tariff rates for CAN
	foreach grp in ag nag {
		foreach file in DutyDetails TradeDetails TariffDetails {
			insheet using CAN08_`grp'_`file'_TL.txt, clear tab names
			sort tl
			save CAN_`grp'_`file'.dta, replace
		}
			
		* Convert all variables in string to allow append later and avoid issues
		* The scalar variables will be re-transformed later.
		insheet using CAN_`grp'_Concession_CO.txt, clear tab names
		tostring _all, replace force
		save CAN_`grp'_Bounds.dta, replace
	}	
	
	* Append the agricultural and non-agricultural datasets
	foreach file in DutyDetails TradeDetails TariffDetails Bounds{
		use CAN_nag_`file'.dta, clear
		append using CAN_ag_`file'.dta
		
	* Check for potential duplicates
		duplicates drop
		sort tl
		save CAN_`file'.dta, replace
	}

****************************************************************************
****************************************************************************
* Correct the database when data is shifted due to problem with original file
* downloaded from IDB

* Reimport the data in csv form if it failed to import all the information. 
* In any case the data MUST NOT be sorted prior to the correction of shifted observations
	foreach grp in ag nag {
		insheet using CAN_`grp'_Concession_CO.txt, clear tab names
		gen agr = "`grp'"
		save CAN_`grp'_Bounds.dta, replace
	}
* It is important not to sort the data but keep the order of the original file.
	use CAN_ag_Bounds.dta, clear
	append using CAN_nag_Bounds.dta, force
	duplicates drop

*	cd "$input/Chapter2/Applications/1_generating a tariff profile/i_importing the data into STATA"
*	do CorrectedshiftedDataFromWITS-IDB-TAO.do


************************************
* THIS PART OF THE DO-FILE CORRECTS THE IMPORT OF BOUND DATA WHEN SOME OBSERVATIONS ARE SHIFTED
* DU TO THE PRESENCE OF ";" OR ":" IN THE DESCRIPTION OF THE PRODUCT LINE. 
* FOR INSTANCE: A PRODUCT LINE IS SPLIT IN TWO OBSERVATIONS. OBS 10 AND 11, WHERE 
* OBS 11 INCLUDES THE VARIABLES THAT SHOULD BE IN OBS 10 BUT WITH WRONG VARIABLE
* NAMES

* IMPORTANT: ALWAYS MAKE SURE THAT WHEN IMPORTING DATA ON BOUNDS DATA, THE WHOLE
* SAMPLE IS IMPORTED. IF IT IS NOT THE CASE, TWO POSSIBILITIES:
* - OPEN THE TXT.FILE IN EXCEL AND SAVE THE TXT.FILE IN CSV FORM
* - OPEN THE TXT.FILE IN EXCEL AND DROP THE FIRST VARIABLE NAME QUERYNAME.

* The Bound Data files has to be openned to run smoothly the code.

* Note that the first line of the shifted observation is actually the
* lagged number id, e.g. obs 10 begins and ends in obs 11. So once renamed
* correctly obs 11 is actually obs 10. Because the data is shifted, most 
* scalar are now string. But Stata does not allow tom merge two 
* variables with the same name but one in string the other in scalar. So
* we first have to treat all variables as string.
	quietly tostring _all, replace force

* drop the lines where there is no information
	drop if basenomenclature == ""

* Create a variable with the number of strings for basenomenclature.
* If there is no problem with the data it should be 22 (e.g. Harmonized System 1996)
	gen lgth = length(basenomenclature)

* Create the identifier for each observation, WITHOUT sorting the data
	gen id = _n
	
	save Bndstemp.dta, replace

	use Bndstemp.dta, replace

* Consider the shifted observations and use a loop to rename the variables
* accordingly. The use of the loop is to avoid reproducing the same command
* for all the variables. Note that for some countries there are more columns so 
* some adjustments have to be made.
	keep if lgth ~= 22
	gen gpagr = agr
	gen grid = id

* rename all variables shorters
	renvars, subst("boundduty" "bndd") 
	renvars, subst("odcduty" "od") 
	renvars, subst("bound" "bnd") 
	renvars, subst("description" "des") 
	renvars, subst("other" "ot") 
	renvars, subst("binding" "bi") 
	renvars, subst("nature" "nt") 
	renvars, subst("status" "st") 
	renvars, subst("safeguard" "safg") 
	renvars, subst("baseduty" "bd") 
	renvars, subst("implementation" "imp") 
	renvars, subst("present" "pr") 
	renvars, subst("text" "tx") 
	renvars, subst("instrument" "ins") 
	renvars, subst("information" "if") 
	renvars, subst("classification" "cls") 
	renvars, subst("special" "spe") 
	renvars, subst("product" "pd") 
	renvars, subst("earlierin" "ein") 
	renvars, subst("base" "bs") 
	renvars, subst("nomenclature" "nom")
	renvars, subst("reporter" "rep")
	renvars, subst("code" "cod")
	rename queryname qr
	rename year yr
	rename certified cert
	rename source so

	describe , varlist fullnames
	global varnames = r(varlist)
	foreach var of global varnames {
		rename `var' `var'_
	}


* Rename the shifted variables with their true name.
	scalar totvarnames = 1
	foreach var of global varnames {
		local i = totvarnames 
		scalar varname_`i' = "`var'"
		scalar totvarnames = totvarnames + 1

		if `i' >= 7 {
			local nr = `i' - 6
			local temp = varname_`nr' 
			rename `temp'_ `var'
		}
	}
	drop agr id
	rename gpagr agr
	rename grid id

* Recover the full name of the variables
	* rename qr queryname 
	* renvars, subst("rep" "reporter")
	* renvars, subst("nom" "nomenclature")
	* renvars, subst("cls" "classification") 
	renvars, subst("if" "information") 	
	renvars, subst("bs" "base") 
	renvars, subst("ein" "earlierin") 
	renvars, subst("pd" "product") 
	renvars, subst("spe" "special") 
	renvars, subst("st" "status") 
	renvars, subst("ins" "instrument") 
	renvars, subst("tx" "text") 
	renvars, subst("pr" "present") 
	renvars, subst("imp" "implementation") 
	renvars, subst("safg" "safeguard") 
	renvars, subst("bndd" "boundduty") 
	renvars, subst("nt" "nature") 
	renvars, subst("bi" "binding") 
	renvars, subst("ot" "other") 
	renvars, subst("des" "description") 
	renvars, subst("bnd" "bound") 
	renvars, subst("od" "odcduty") 
	renvars, subst("bd" "baseduty") 

	rename so source 
	rename cert certified 
	*rename qr queryname 
	drop *_ 

	sort id
	save "ShiftedData.dta", replace

* This file with shifted data has to be appended with the original file
	use "Bndstemp.dta", clear
	drop if lgth ~= 22
	append using "ShiftedData.dta", force

* Make some adjustments
	drop productdescription
	levelsof basenomenclature 
	replace basenomenclature = `r(levels)'
	
	levelsof reportercode
	replace reportercode = `r(levels)'
	
	levelsof reporter
	replace reporter = `r(levels)'

	levelsof year
	replace year = `r(levels)'

	replace productclassification = "HS - WTO Agricultural Products Definition" if agr == "ag" & productclassification  == ""
	replace productclassification = "HS - WTO  Non-agricultural Products Definition" if agr == "nag" & productclassification  == ""  

	drop if tl == ""
	replace queryname = "" if queryname ~= ""
	format queryname %12s
	drop agr lgth 
	sort id
	drop id 

* Destring the numerical variable
	destring  bounddutyav odcdutyav basedutyav  implementationfrom implementationto , replace

* Erase the temporary files
	erase "Bndstemp.dta"
	erase "ShiftedData.dta"
************************************



	cd "$input/Chapter2/Datasets"
	save CAN_Bounds.dta, replace


*	Erase construction files

foreach grp in ag nag {
	foreach file in DutyDetails TradeDetails TariffDetails {
	erase CAN_`grp'_`file'.dta
	}
	}
*
foreach file in 	CAN_ag_Bounds.dta CAN_Nag_Bounds.dta 							///
					CAN_TariffDetails.dta 	{
erase `file'
	}

****************************************************************************
****************************************************************************
	
exit
exit
exit
