****************************************************************************
*** MODULE 1 - THEME 2 - ANALYZING TARIFF PROFILES - APPLICATION 1  ******** 
****************************************************************************




* The selected country is Canada for 2007. 
* Also it is important to check all the products lines to download the full
* database.

* Data source: Bound, Tariff and Trade details available at wits.worldbank.org 
*		   or at http://tao.wto.org

* Data used:	Tariffs.dta;
* See ImportDataFromWITS-IDB-TAO.do

* Data saved:	summary.dta;
*			freq.dta;
*


********* PRELIMINARY STEP *********
* Set memory and path 
	clear all
	set mem 300m
	set matsize 800
	graph drop _all

********* IMPORT DATABASE *********
	cd "$input/Chapter2/Applications/1_generating a tariff profile/i_importing the data into STATA"  
	run ImportDataFromWITS-IDB-TAO

	
* Open database
	
	cd "$input/Chapter2/Datasets"


* Goal: Reproduce Country Profile Table in the World Tariff Profiles
* source: http://www.wto.org/english/res_e/reser_e/tariff_profiles_e.htm
*	    + Nomenclature for HS classification


********************************************************************
******       Tariff and Imports: Summary and duty ranges      ****** 
********************************************************************

***** Simple average final bound ***** 
	use CAN_Bounds.dta, clear
	drop if tls == "'00'"
	
* Create a dummy to distinguish between agriculture and non-agricultural
* products by creating 
	gen ag = 0 if productclassification == "HS - WTO  Non-agricultural Products Definition"
	replace ag = 1 if productclassification == "HS - WTO Agricultural Products Definition"
	label var ag "1 if agricultural product"

* Create the hs6 classification based on hs8 (tl)
* Note that for some tariff lines, there are sub-groups to the hs8
* classification
	gen hs6 = substr(tl,1,6+1) + "'"

* Create a dummy for non ad-valorem duty (== "Specific duty" | == "Mixed duty" | == "Compound duty" | == "Technical duty")
	gen nav = 0
	replace nav = 1 if bounddutynature ~= "A"
	label var nav "1 if non ad-valorem duty"

* import the full classification
* at the hs6 level
	sort hs6 ag
	merge hs6 ag using "HS02Complete.dta"
	drop _merge

* Consider only the variables used and save the file
	keep tl tls ex bounddutyav bounddutybindingstatus nav hs6 ag 
	save CAN_Bounds_new.dta, replace
 
* Compute the simple (hs sub-heading) average final bound. But first, 
* pre-aggregate at the hs-6 level
* Note that in Stata if there is a missing value for NAV, it is considered as zero when
* the data is collapsed. To avoid this issue, we need to drop the missing values that
* are NAV observations, for the NAV share they have to be compute in a different file.
	use CAN_Bounds_new.dta, clear
	destring bounddutyav, replace
      drop if bounddutyav == . & nav ~= .
	drop if bounddutybindingstatus ~= "B" 

	collapse(mean) bounddutyav, by(tl hs6 ag )
	collapse(mean) bounddutyav, by(hs6 ag )
	
	egen Total = mean(bounddutyav)
	egen Ag = mean(bounddutyav) if ag == 1
	egen NonAg = mean(bounddutyav) if ag == 0

* Save the results and export them in txt file, but drop duplicates
	collapse(max) Total Ag NonAg 
	label var Total "Simple average final bound Total"
	label var Ag "Simple average final bound Agricultural"
	label var NonAg "Simple average final bound Non-Agricultural"

	gen Summary = "Simple average final bound"	
	order Summary Total Ag NonAg
	save "CAN_Bounds_avg.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_Bounds_avg.txt", replace
	cd "$input/Chapter2/Datasets"


* Compute the binding coverage 
	use "CAN_Bounds_new.dta", clear
	drop if tls == "'00'"
	replace nav = -999 if bounddutyav == . & nav == .

	gen bind = 1
	replace bind = 0 if bounddutybindingstatus ~= "B"

	collapse(mean) bounddutyav nav bind, by(tl hs6 ag)
	collapse(mean) bounddutyav nav bind, by(hs6 ag)

	egen binding = sum(bind)
	gen toths6 = _N
 	gen BindingCoverage = binding / toths6  * 100 

	bys ag: egen binding_byag = sum(bind)
	bys ag: gen toths6_byag = _N 
	bys ag: gen BindingCoverageNAg  = binding_byag / toths6_byag * 100 if ag == 0 

* Compute the share of non ad-valorem duties.
	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl * 100
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0

* Save the results and export them in txt file, but drop duplicates 
* and save the results for Coverage and NAV in 2 different files
	collapse(max) BindingCoverage BindingCoverageNAg  TotalNAVshare TotalNAV_Agshare  TotalNAV_NonAgshare 
	save "CAN_Bounds_coverage.dta", replace

	* Results for NAV
	keep Total*
	rename TotalNAVshare Total
	label var  Total "Total share of non ad-valorem duty in bound duty"
	rename TotalNAV_Agshare Ag
	label var Ag "Total share of non ad-valorem duty in bound duty for Agricultural products"
	rename TotalNAV_NonAgshare NonAg
	label var NonAg "Total share of non ad-valorem duty in bound duty for non-Agricultural products"
	gen Summary = "Share of non ad-valorem duty in bound duty"
	order Summary Total Ag NonAg
	save "CAN_Bounds_NAV_share.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_Bounds_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"

	* Results for Coverage
	use "CAN_Bounds_coverage.dta", clear
	keep Binding*
	rename BindingCoverage Total 
	label var Total "Binding coverage"
	rename BindingCoverageNAg NonAg 
	label var NonAg "Binding coverage Non-Agricultural"
	gen Summary = "Binding coverage"
	save "CAN_Bounds_coverage.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_Bounds_coverage.txt", replace
	cd "$input/Chapter2/Datasets"

***** Simple average MFN applied ***** 
	use "CAN_DutyDetails.dta", clear
		
	* For some tariff lines at 8 digit there are sub-products given
	* by tls with '00', '01', '02', ..., where '00' is the average
	* of the sub-products. So they have to be dropped to compute
	* the average:
	drop if tls == "'00'"
	keep if nationaldescription == "MFN applied duty rates"

* Create dummy to distinguish between agriculture and non-agricultural
* products by creating 
	gen ag = 0 if classification == "HS - WTO  Non-agricultural Products Definition"
	replace ag = 1 if classification == "HS - WTO Agricultural Products Definition"
	label var ag "1 if agricultural product"

* Create dummy for non ad-valorem duty (== "Specific duty" | == "Mixed duty")
	gen nav = 0
	replace nav = 1 if description3 ~= "Ad valorem duty"
	label var nav "1 if non ad-valorem duty"

* The data uses harmonized system nomenclature 2007
* Create the hs6 classification based on hs8 (tl)
	gen hs6 = substr(tl,1,6+1) + "'"

* Save file to be used to compute the trade weighted MFN duty
	sort tl ag
	save "CAN_MFN.dta", replace

* Compute the average for the HS6 sub-heading by first pre-aggregating at 6-digit level
	use "CAN_MFN.dta", clear

	drop if avdutyrate == . & nav ~= .
	collapse(mean) avdutyrate nav, by(hs6 ag)
	label var avdutyrate "Simple average tariff lines, dutiable or duty-free items"

	egen Total = mean( avdutyrate)
	egen Ag = mean( avdutyrate) if ag == 1
	egen NonAg = mean( avdutyrate) if ag == 0

* Save the average and the share in two files and export the results to a table, but first drop
* the duplicates
	collapse(max) Total Ag NonAg 
	label var Total "Simple average MFN applied Total"
	label var Ag "Simple average MFN applied Agricultural"
	label var NonAg "Simple average MFN applied Non-Agricultural"
	gen Summary = "Simple average MFN applied"	

	order Summary Total Ag NonAg
	save "CAN_MFN_avg.dta", replace


* Compute the share of non ad-valorem duties.
	use "CAN_MFN.dta", clear

	sort hs6 ag
	merge hs6 ag using "HS07Complete.dta"
	drop _merge
	replace nav = -999 if avdutyrate == . & nav == .

	collapse(mean) avdutyrate nav, by(tl hs6 ag)
	collapse(mean) avdutyrate nav, by(hs6 ag)

	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0


* Save the average and the share in two files and export the results to a table, but first drop
* the duplicates
	rename TotalNAVshare Total
	rename TotalNAV_Agshare Ag
	rename TotalNAV_NonAgshare NonAg
	collapse(max) Total Ag NonAg 
	gen Summary = "Share of non ad-valorem duty in MFN applied"
	save "CAN_MFN_NAV_share.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_MFN_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"
	

***** Trade weighted average MFN applied ***** 
*****     and Imports in billion US$     ***** 
* Compute the trade weighted average for the HS sub-heading
* Note that the imports and weighted average are computed by
* tariff line and not by HS sub-heading

* Merge with trade details file to compute the trade weighted average
* Note that in the trade files, there are no informations on 
* sub-product lines	
* Consider only total imports from "All Origins" and the average at the hs6 level

* First, prepare the import data to be merged by considering only total
* imports
	use "CAN_TradeDetails.dta", clear
	keep tl name value 
	keep if name == "All Origins"
	label var value "import values"
	sort tl
	save "CAN_Imp.dta", replace

* Aggregate the sub-products at hs8
	use "CAN_MFN.dta", clear
	collapse(mean) avdutyrate nav, by(tl hs6 ag)

* Merge with the duty data
	sort tl
	merge tl using "CAN_Imp.dta"
	keep if _merge == 3
	drop _merge
	sort hs6
	save "CAN_MFN_trade.dta", replace

* Aggregate at the HS6-subheading. Note that in TAO they compute
* by tariff lines and not by HS sub-headings
	collapse (mean) avdutyrate nav (sum) value, by(hs6 ag)
	label var avdutyrate "Simple average tariff lines, dutiable or duty-free items"
	label var ag "1 if agricultural product"
	label var value "imports value"
	label var nav "1 if non ad-valorem duty"

	*replace nav = 0 if nav < 1

	egen Mtot = total(value) 
	egen MtotAg = total(value) if ag == 1
	egen MtotNonAg = total(value) if ag == 0
	egen Total = total( (avdutyrate * value)/Mtot )
	egen Ag = total( (avdutyrate * value)/MtotAg ) if ag == 1
	egen NonAg = total( (avdutyrate * value)/MtotNonAg ) if ag == 0

* Save file and export the results to a table, but first drop
* the duplicates 
	collapse(max) Total Ag NonAg Mtot MtotAg MtotNonAg
	replace Mtot = Mtot / 1000000
	replace MtotAg = MtotAg / 1000000
	replace MtotNonAg = MtotNonAg / 1000000

	label var Total "Trade weighted average MFN applied Total"
	label var Ag "Trade weighted average MFN applied Agricultural"
	label var NonAg "Trade weighted average MFN applied Non-Agricultural"
	save "CAN_MFN_trade_avg.dta", replace

* Report results for trade-weighted average and imports
* in two different lines
	keep M*
	rename Mtot Total
	rename MtotAg Ag
	rename MtotNonAg NonAg
	gen Summary = "Imports in billion US$"
	order Summary Total Ag NonAg
	save "temp.dta", replace

	use "CAN_MFN_trade_avg.dta", clear
	keep Total Ag NonAg
	gen Summary = "Trade weighted average MFN applied"
	order Summary Total Ag NonAg
	append using "temp.dta"
	erase "temp.dta"
	save "CAN_MFN_trade_avg.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_MFN_trade_avg.txt", replace
	cd "$input/Chapter2/Datasets"

	
	
* Compute the share of non ad-valorem duty.
	use "CAN_MFN_trade.dta", clear
	replace nav = -999 if avdutyrate == . & nav == .
	collapse(mean) avdutyrate nav, by(hs6 ag)

	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0

* Save file and export the results to a table, but first drop
* the duplicates 
	rename TotalNAVshare Total
	rename TotalNAV_Agshare Ag
	rename TotalNAV_NonAgshare NonAg
	collapse(max) Total Ag NonAg 
	gen Summary = "Share of non ad-valorem duty in Imports"
	save "CAN_MFN_trade_NAV_share.dta", replace
		
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_MFN_trade_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"
	

* Create a table with the different results
	use "CAN_Bounds_avg.dta", clear
	append using "CAN_Bounds_NAV_share.dta"
	append using "CAN_MFN_avg.dta"
	append using "CAN_MFN_NAV_share.dta"
	append using "CAN_MFN_trade_avg.dta"
	append using "CAN_MFN_trade_NAV_share.dta"
	save "CAN_summary.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_summary.txt", replace
	cd "$input/Chapter2/Datasets"


	
	
***** Frequency distribution ***** 
* The frequency distribution is based on the complete classification, which
* was merged previously. In the TAO, the frequency is computed at the 
* tariff line available in the file while in the table it is at the hs6 level 

***** Final Bound ***** 
	use "CAN_Bounds_new.dta", clear
	drop if tls == "'00'"
*	drop if bounddutyav == .
*	collapse (mean) bounddutyav , by(tl hs6 ag)
*	sort hs6
*	save "CAN_BND_freq.dta", replace

* Merge with the full classification 
*	use "ProdGrp_hs96at6dig.dta", clear
*	sort hs6
*	merge hs6 using "CAN_BND_freq.dta"

* Create the range for the frequency distribution
	gen range = "Duty-free" if bounddutyav == 0
	replace range = "0 <= 5" if bounddutyav > 0 & bounddutyav <= 5
	replace range = "5 <= 10" if bounddutyav > 5 & bounddutyav <= 10
	replace range = "10 <= 15" if bounddutyav > 10 & bounddutyav <= 15
	replace range = "15 <= 25" if bounddutyav > 15 & bounddutyav <= 25
	replace range = "25 <= 50" if bounddutyav > 25 & bounddutyav <= 50
	replace range = "50 <= 100" if bounddutyav > 50 & bounddutyav <= 100
	replace range = "> 100" if bounddutyav > 100
	replace range = "N.A." if bounddutyav == . 


* Compute the frequency distribution
	collapse (mean) bounddutyav , by(range hs6 tl ag)
	*collapse (mean) bounddutyav , by(range hs6 ag)
	bys ag: gen nrbnd = _N 
	bys range ag: gen freqbnd = _N 
	gen freqBndAg = freqbnd / nrbnd *100 if ag == 1
	gen freqBndNonAg = freqbnd / nrbnd *100 if ag == 0

* Drop the duplicates and save the file
	collapse(max) fre*Ag, by(range)
	label var range "Distribution range" 
	label var freqBndAg "Frequency distribution for applied bound duty in agricultural products"
	label var freqBndNonAg "Frequeency distribution for applied bound duty in non-agricultural products"
	sort range
	save "CAN_BND_freq.dta", replace

***** MFN applied ***** 
	use "CAN_MFN.dta", clear
	drop if basenomenclature == ""	

* Pre-aggregate the data at 8-digits
	collapse (mean) avdutyrate nav, by(tl hs6 ag)

* If there are an ad-valorem and non ad-valorem for a given tariff line, I consider
* only the ad-valorem
	*replace nav = 0 if nav < 1

* Merge with the full classification 
	sort hs6
	merge hs6 using "ProdGrp_hs07at6dig.dta"

* Create the range for the frequency distribution
	gen range = "Duty-free" if avdutyrate == 0
	replace range = "0 <= 5" if avdutyrate > 0 & avdutyrate <= 5
	replace range = "5 <= 10" if avdutyrate > 5 & avdutyrate <= 10
	replace range = "10 <= 15" if avdutyrate > 10 & avdutyrate <= 15
	replace range = "15 <= 25" if avdutyrate > 15 & avdutyrate <= 25
	replace range = "25 <= 50" if avdutyrate > 25 & avdutyrate <= 50
	replace range = "50 <= 100" if avdutyrate > 50 & avdutyrate <= 100
	replace range = "> 100" if avdutyrate > 100
	replace range = "NAV" if nav == 1
	replace range = "N.A." if avdutyrate == . & nav == .

* Compute the frequency in % of the number of tariff lines
	collapse (mean) avdutyrate , by(range tl ag)
	bys ag: gen nrduty = _N
	bys range ag: gen freqduty = _N 
	gen freqAg = freqduty / nrduty *100 if ag == 1
	gen freqNonAg = freqduty / nrduty *100 if ag == 0

* Save the results
	collapse(max) fre*Ag, by(range)
	label var range "Distribution range" 
 	label var freqAg "Frequency distribution for applied MFN duty in agricultural products"
	label var freqNonAg "Frequency distribution for applied MFN duty in non-agricultural products"
	sort range
	save "CAN_MFN_freq.dta", replace


***** Imports ***** 
* Open file where you already merged trade and duties
	use "CAN_MFN_trade.dta", clear
	drop if name == ""	
	collapse (sum) value (mean) avdutyrate nav , by(tl hs6 ag)

* Create the range for the frequency distribution
	gen range = "Duty-free" if avdutyrate == 0
	replace range = "0 <= 5" if avdutyrate > 0 & avdutyrate <= 5
	replace range = "5 <= 10" if avdutyrate > 5 & avdutyrate <= 10
	replace range = "10 <= 15" if avdutyrate > 10 & avdutyrate <= 15
	replace range = "15 <= 25" if avdutyrate > 15 & avdutyrate <= 25
	replace range = "25 <= 50" if avdutyrate > 25 & avdutyrate <= 50
	replace range = "50 <= 100" if avdutyrate > 50 & avdutyrate <= 100
	replace range = "> 100" if avdutyrate > 100
	replace range = "NAV" if nav == 1
	replace range = "N.A." if avdutyrate == . & nav == .

* Compute the frequency
	drop if value == .
	collapse (sum) value, by(range hs6 ag)
	bys ag: egen Mtot = total(value)
	bys ag range: egen Mtotrg = total(value)
	gen freqMAg = Mtotrg /Mtot * 100 if ag == 1
	gen freqMNonAg = Mtotrg /Mtot * 100 if ag == 0

* Save file
	collapse(max) freq*Ag, by(range)
	label var range "Distribution range" 
	label var freqMAg "Frequency distribution for imports in agricultural products"
	label var freqMNonAg "Frequency distribution for imports in agricultural products"
	sort range 
	save "CAN_Imp_freq.dta", replace


***** Create the table with the results ***** 
* Merge the different files to create one single table 
	clear
	set obs 10
	gen id = _n
	gen range = "Duty-free" if id == 1
	replace range = "0 <= 5" if id == 2
	replace range = "5 <= 10" if id == 3
	replace range = "10 <= 15" if id == 4
	replace range = "15 <= 25" if id == 5
	replace range = "25 <= 50" if id == 6
	replace range = "50 <= 100" if id == 7
	replace range = "> 100" if id == 8
	replace range = "N.A." if id == 9
	replace range = "NAV" if id == 10

	sort range
	merge range using "CAN_BND_freq.dta"
	drop _merge
	sort range
	merge range using "CAN_MFN_freq.dta"
	drop _merge
	sort range
	merge range using "CAN_IMP_freq.dta"
	drop _merge
	sort id

	foreach var in freqBndAg freqBndNonAg freqAg freqNonAg freqMAg freqMNonAg {
		replace `var' = 0 if `var' == .
	}
	drop if range == "N.A."

* Save the file and export the results into a table
	label var range "Distribution range" 
	label var freqBndAg "Frequency distribution for applied bound duty in agricultural products"
	label var freqBndNonAg "Frequeency distribution for applied bound duty in non-agricultural products"
 	label var freqAg "Frequency distribution for applied MFN duty in agricultural products"
	label var freqNonAg "Frequency distribution for applied MFN duty in non-agricultural products"
	label var freqMAg "Frequency distribution for imports in agricultural products"
	label var freqMNonAg "Frequency distribution for imports in agricultural products"
	save "CAN_freq.dta", replace
	
	cd "$input/Chapter2/Applications/1_generating a tariff profile/Results"
	outsheet using "CAN_freq.txt", replace
	cd "$input/Chapter2/Datasets"


*	Erase construction files

	foreach bit in 	BND_freq freq Imp_freq MFN_freq summary Imp MFN_avg MFN_NAV_share MFN_trade MFN_trade_avg MFN_trade_NAV_share	///
					Bounds_avg Bounds_coverage Bounds_NAV_share MFN Bounds Bounds_new TradeDetails DutyDetails	{
	erase CAN_`bit'.dta
	}
*

****************************************************************************
****************************************************************************
		
	
exit
exit
exit
