****************************************************************************
********* MODULE 1 - THEME 2 - ANALYZING PREFERENTIAL MARKET ACCESS  ******** 
****************************************************************************



* Compute the value of preferential market access The selected country is CANADA for 2007. The reason is 
* that it includes NON-ADVALOREM TARIFFS.

* Data source:	Marco Fugazza and Alessandro Nicita, 2010. "The Value of
*			Preferential Market Access"

* Data used: 	PMA_MEX.dta;
* 
* Data save:	RPM_MEX.dta;
*
*




********* PRELIMINARY STEP *********
* Set memory and path 
	clear all
	set mem 300m
	set matsize 800
	graph drop _all


* Open database
	
	cd "$input/Chapter2/Datasets"


********* IMPORT DATABASE *********

* Open the database and make some adjustments
	use "PMA_MEX.dta", clear 
	
********* COMPUTE THE PREFERENTIAL MARKET ACCESS *********

* Compute the TTRI measure
	bys ccode year pcode: egen num = sum(exp * T * eps)
 	bys ccode year pcode: egen den = sum(exp * eps)
	gen TTRI_elas = num / den
	label var TTRI_elas "Tariff trade restrictiveness index"

	bys ccode year pcode: egen num_ = sum(exp * T )
 	bys ccode year pcode: egen den_ = sum(exp)
	gen TTRI_noelas = num_ / den_
	label var TTRI_noelas "Tariff trade restrictiveness index without elasticities as weights"

* Compute the weighted average tariff for competitors at the hs level (Twc)
	bys ccode year hs6: egen TotalexpT = sum(exp * T)
	bys ccode year hs6: egen Totalexp = sum(exp)
	gen Twc2 = (TotalexpT - exp * T) / (Totalexp - exp)
	label var Twc "Weighted average tariff for competitors at the hs level"

* Compute the RPM measure which corresponds to the average advantage 
* (or disadvantage) of exporter (pcode) in entering the importer (ccode) market
* Calculate the sum across products of the numerator and denominator of the weigthed
* averages (for competitors (1) and own tariff (2)) with and without the elasticities
* as weights.
	bys ccode year pcode: egen num2 = sum(exp * Twc * eps)
	gen TTRI_others_elas = num2 / den
	gen RPM_elas = TTRI_others_elas - TTRI_elas
	label var RPM_elas "Relative preferential margin with elasticities as weights"

	bys ccode year pcode: egen num2_ = sum(exp * Twc)
	gen TTRI_others_noelas = num2_ / den_
	gen RPM_noelas = TTRI_others_noelas - TTRI_noelas
	label var RPM_noelas "Relative preferential margin without elasticities as weights"


* Compute the trade-weighted average for MEX
	bys ccode pcode year: egen exports = sum(exp)
	keep ccode year pcode exports TTRI* RPM*
	duplicates drop
	bys ccode year: egen Totalexports = sum(exports)

	bys ccode year: egen TTRI_elas_bar = mean( TTRI_elas )
	label var TTRI_elas_bar "TTRI simple average"
	bys ccode year: egen TTRI_elas_sd = sd( TTRI_elas )
	label var TTRI_elas_sd "TTRI simple standard deviation"

	bys ccode year: egen TTRI_noelas_bar = mean( TTRI_noelas ) 
	bys ccode year: egen TTRI_noelas_sd = sd( TTRI_noelas ) 

	bys ccode year: egen TTRI_elas_wbar = total((TTRI_elas * exports) / Totalexports)
	label var TTRI_elas_wbar "TTRI trade weighted average"
	bys ccode year: egen TTRI_elas_wsd = sd((TTRI_elas * exports) / Totalexports)
	label var TTRI_elas_wsd "TTRI trade weighted standard deviation"
	bys ccode year: egen TTRI_noelas_wbar = total((TTRI_elas * exports) / Totalexports)
	bys ccode year: egen TTRI_noelas_wsd = sd((TTRI_elas * exports) / Totalexports)
		
	bys ccode year: egen RPM_elas_bar = mean( RPM_elas )
	label var RPM_elas_bar "RPM simple average"
	bys ccode year: egen RPM_elas_sd = sd( RPM_elas )
	label var RPM_elas_sd "RPM simple standard deviation"

	bys ccode year: egen RPM_noelas_bar = mean( RPM_noelas ) 
	bys ccode year: egen RPM_noelas_sd = sd( RPM_noelas ) 

	bys ccode year: egen RPM_elas_wbar = total( (RPM_elas * exports) / Totalexports )
	label var RPM_elas_wbar "RPM trade weighted average"
	bys ccode year: egen RPM_elas_wsd = sd( (RPM_elas * exports) / Totalexports )
	label var RPM_elas_wsd "RPM trade weighted standard deviation"

	bys ccode year: egen RPM_noelas_wbar = total( (RPM_noelas * exports) / Totalexports )
	bys ccode year: egen RPM_noelas_wsd = sd( (RPM_noelas * exports) / Totalexports )
	
	keep year ccode TTRI*bar RPM*bar TTRI*sd RPM*sd
	duplicates drop

* Save the results and export results
	save "RPM.dta", replace
	keep  year ccode TTRI_elas_bar  TTRI_elas_wbar  RPM_elas_bar RPM_elas_wbar

	rename TTRI_elas_bar TTRIsimpleavg 
	rename TTRI_elas_wbar TTRIweightedav

	rename RPM_elas_bar RPMsimpleavg 
	rename RPM_elas_wbar RPMweightedav

	cd "$input/Chapter2/Applications/2_value of preferential margins/Results"
	outsheet using "RPM.txt", replace
	cd "$input/Chapter2/Datasets"

	
*	Erase construction file
erase 	RPM.dta

***************
exit
exit
exit

