****************************************************************************
****    MODULE 1 - THEME 2 - ANALYZING TRADE POLICY - EXERCISE 3    ******** 
****************************************************************************



* The selected countries are Colombia (COL) and Japan (JPN).

* Data source: Trade and production data are from the database " Trade, 
*		   Protection and Production 1976-2004 " constructed by the World 
*		   Bank (Nicita and Olarreaga 2006), and are available at 
*		   http://go.worldbank.org/EQW3W5UTP0
* 		   They only refer to manufacturing industries.

* Download the file TPP_rev1.csv and use TPP.do to import the data and prepare the
* TPP.dta STATA data file that is used for this exercise 




********* PRELIMINARY STEP *********
* Set memory and path 
	clear all
	set mem 300m
	set matsize 800
	graph drop _all

	
	
* Open database
	
	cd "$input/Chapter2/Datasets"


*********    QUESTIONS    ********* 

* 1. PRELIMINARIES 
* Open the database
 	use "TPP.dta", clear



*a) 	Select a country. Check what variables and what years are available
*   for this country. [Hint: Some developing countries may 
*	have a large number of missing observations. Make sure you select a country 
*	for which enough information is available]
*	
*	According to the data description handout, data covers 1976-2004, with 
* 	missing observation for several variables.
*	Absolute financial indicators are measured in 1000 US-Dollars, whereas 
*	unit values are expressed in USD per kilogram and physical units are 
*	given in Kilogram.

	summarize if ccode == "COL"
	summarize if ccode == "JPN"

* b)	Indicate what nomenclature is used and at what degree of disaggregation
*	the data is available.
*	The isic3d_3dig variable is the Sector-Identifier which divides the 
* 	economic activities into 28 sectors (isic identifier from 311 to 390).
	describe isic3d_3dig
	
* 2.	Average tariffs and their determinants
* a)	Report in a table descriptive statistics for the tariffs: simple and 
*	weighted averages of effectively applied (i.e. taking preferences into account) 
*	and MFN applied tariff, and corresponding median, standard deviation, minimum 
*	and maximum, all calculated for the 28 3-digit subheadings provided in the database. 

* Open the database 	
	use "TPP.dta", clear
	
* Construct table with descriptive statistics about tariffs, including average, 
* median, standard deviation, min and max.
* 2 possibilities: - apply the command tabstat to do it automatically
*			 - compute it manually and export in a table
	* Solution 1:
	tabstat tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn if ccode == "COL", statistics( mean median sd min max ) by(sector) columns(variables)
	tabstat tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn if ccode == "JPN", statistics( mean median sd min max ) by(sector) columns(variables)
	* tabstat tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn if ccode == "COL", statistics( mean median sd min max ) by(sector isic3d_3dig) columns(variables)
	* tabstat tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn if ccode == "JPN", statistics( mean median sd min max ) by(sector isic3d_3dig) columns(variables)


	* Solution 2:
	foreach tariff in tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn {
		sort ccode isic3d_3dig
		by ccode isic3d_3dig: egen `tariff'1 = mean(`tariff')
		by ccode isic3d_3dig: egen `tariff'2 = median(`tariff')
		by ccode isic3d_3dig: egen `tariff'3 = sd(`tariff')
		by ccode isic3d_3dig: egen `tariff'4 = min(`tariff')
		by ccode isic3d_3dig: egen `tariff'5 = max(`tariff')
	}

	keep ccode isic3d_3dig tar*1 tar*2 tar*3 tar*4 tar*5
	duplicates drop
	reshape long tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn, i(ccode isic3d_3dig) j(stats)
	gen statistics = "mean" if stats == 1
	replace statistics = "median" if stats == 2
	replace statistics = "sd" if stats == 3
	replace statistics = "min" if stats == 4
	replace statistics = "max" if stats == 5
	drop stats
	order ccode isic3d_3dig statistics tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn
	label var statistics "statistics name"
	label var tar_savg_ahs "simple average of applied tariffs on imports"
	label var tar_iwahs "weighted average of applied tariffs on imports"
	label var tar_savg_mfn  "simple average import tariff for most favored ntion MFN"
	label var tar_iwmfn "weighted average tariff rate for MFN"

	save "AverageTariff.dta", replace	

	cd "$input/Chapter2/Exercises/3_tariff analysis/Results"
	outsheet isic3d_3dig statistics tar* if ccode == "COL" using "AverageTariff_COL.txt", replace
	outsheet if ccode == "JPN" using "AverageTariff_JPN.txt", replace


* b)	Draw a histogram of tariffs and comment on their distribution.

* Open the database 	
		cd "$input/Chapter2/Datasets"
		use "TPP.dta", replace
		
* Draw a histogram of tariffs and comment on their distribution
cd "$input/Chapter2/Exercises/3_tariff analysis/Results"

		foreach country in COL JPN {
		foreach tariff in tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn {
			histogram `tariff' if ccode == "`country'", title(Tariff Distribution in `country') legend(off)
			graph save Graph "Hist_`tariff'_`country'.gph", replace
		}
		}


* 3.	Tariffs and NTBs
* a)	For each of the two countries, draw a scatter plot where 
*	each point is a sector, tariffs are on the horizontal axis and NTB 
*	ad-valorem equivalents (AVE) are on the vertical one. On the basis of your
* 	scatter plot, are tariffs and NTBs complements or substitutes? Explain. 
*	[Hint: When the number of zero values is high, it is best to drop them 
*	from the plot to see a clearer picture]

* Open the database 	
		cd "$input/Chapter2/Datasets"
		use "TPP.dta", replace

* Create the scatter and save it
cd "$input/Chapter2/Exercises/3_tariff analysis/Results"

	foreach country in COL JPN {
		foreach tariff in tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn {
			twoway (scatter ave_core_sim `tariff' if ccode == "`country'"), title(Tariffs versus NTBs in `country') legend(off)
			graph save Graph "Scatter_`tariff'_vs_ave_`country'.gph", replace
		}
	}

* Re-do it but without zero values
	foreach country in COL JPN {
		foreach tariff in tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn {
			twoway (scatter ave_core_sim `tariff' if ccode == "`country'" & (  ave_core_sim > 0 & `tariff' > 0   )), title(Tariffs versus NTBs in `country' (no zero)) legend(off)
			graph save Graph "Scatter_`tariff'_vs_ave_`country'_no0.gph", replace
		}
	}

* Note that if there is a positive (negative) correlation, then both are complements (substitute) 
* with each other.


* 4.	Determinants of tariffs
* a)	For the full sample of countries, calculate import-penetration ratios for each 
*	sector and their change between the first and last three years of the sample. 
*	[Hint: If there are too many missing observations for the period 2002-2004, 
*	consider 1999-2001 or 1998-2000 for the end period]

	* The import-penetration ratio for good j is defined as muj = Mj/Cj 
	* where: Mj is imports of good j for a given year
	*	   Cj is domestic consumption (final demand) of the same good in the 
	*	   same year
	
* Open the database 	
		cd "$input/Chapter2/Datasets"
		use "TPP.dta", replace

* Compute the import-penetration ratio
	gen M_ = imp_tv
	gen C_ = imp_tv + output
	gen mu = M_ / C_
	label var mu "Import-Penetration"
	save "TPPwithimppen.dta", replace

* Compute the rate of growth of import-penetration between 1983-1985 and 2002-2004.
	sort ccode isic3d_3dig 
	by ccode isic3d_3dig: egen mu_83_85 = mean(mu) if year >= 1983 & year <= 1985
	label var mu_83_85 "Average Import-Penetration for 1983-1985"
	*by ccode isic3d_3dig: egen mu_02_04 = mean(mu) if year >= 2002 & year <= 2004	
	*by ccode isic3d_3dig: egen mu_02_04 = mean(mu) if year >= 2000 & year <= 2002	
	by ccode isic3d_3dig: egen mu_02_04 = mean(mu) if year >= 1998 & year <= 2000	

	label var mu_02_04 "Average Import-Penetration for 2002-2004"
	collapse(mean) mu_83_85 mu_02_04, by(ccode isic3d_3dig)
	gen mugrate = (mu_02_04 - mu_83_85)/mu_83_85
	label var mugrate "Growth Rate of Import-Penetration"

* Save the results in a Stata file
	sort ccode isic3d_3dig
	save "ImportPenetrationRate.dta", replace

* Create a table with the different growth rates in a txt file
	order ccode isic3d_3dig mugrate
	
	cd "$input/Chapter2/Exercises/3_tariff analysis/Results"

	outsheet ccode isic3d_3dig mugrate if ccode == "COL" using  "IP_COL.txt", replace
	outsheet ccode isic3d_3dig mugrate if ccode == "JPN" using  "IP_JPN.txt", replace


* b)	Calculate establishment size as the ratio of employees to establishments, the 
*	proportion of female workers, and wages per employee. 
	
* Open the database 
		cd "$input/Chapter2/Datasets"
		use "TPPwithimppen.dta", replace

* Compute the different ratios
	gen estabsize = n_employees/n_establ
	label var estabsize "establishment size"
	gen femalework = n_female_emp/n_employees
	label var femalework "proportion of female workers"
	gen wagepe = wage_bill/n_employees
	label var wagepe "wage per employee"

* Save the file
	keep ccode year isic3d_3dig tar_savg_ahs tar_iwahs tar_savg_mfn tar_iwmfn ave_core_sim ave_core_sim ave_core_wgt estabsize femalework wagepe mu
	save "Ratios.dta", replace

* c)	Regress average tariffs and NTBs on these variables and comment on any results 
*	you may get.
	
	* Open the database
		use "Ratios.dta", clear
	
	* Specifiy the panel identifier
		egen id = group(ccode isic3d_3dig)
		tsset id year	

	* transform the variables in logarithm
		foreach var in estabsize wagepe {
			gen ln_`var' = ln(`var')
		}

		gen ln_tar_savg_ahs = ln(tar_savg_ahs + 1)
		gen ln_femalework = ln(femalework + 1)
		gen ln_mu = ln(mu + 1)

	* Estimate with full sample (world)
cd "$input/Chapter2/Exercises/3_tariff analysis/Results"
		
		xtreg tar_savg_ahs estabsize femalework wagepe, fe vce(robust)
		outreg2 using "Regression.txt", replace bracket ctitle("Average Tariffs")	
		xtreg tar_savg_ahs estabsize femalework wagepe mu, fe vce(robust)
		outreg2 using "Regression.txt", replace bracket ctitle("Average Tariffs")	

		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe, fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe ln_mu, fe vce(robust)
		outreg2 using 

	* Estimate with OECD-NonOECD
		xtreg tar_savg_ahs estabsize femalework wagepe if (ccode=="ARG" | ccode=="BRA" | ccode=="CHN" | ccode=="IND" | ccode=="KEN") | (ccode=="AUS" | ccode=="CAN" | ccode=="DEU" | ccode=="JPN" | ccode=="USA"), fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
		xtreg tar_savg_ahs estabsize femalework wagepe mu if (ccode=="ARG" | ccode=="BRA" | ccode=="CHN" | ccode=="IND" | ccode=="KEN") | (ccode=="AUS" | ccode=="CAN" | ccode=="DEU" | ccode=="JPN" | ccode=="USA"), fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	

		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe if (ccode=="ARG" | ccode=="BRA" | ccode=="CHN" | ccode=="IND" | ccode=="KEN") | (ccode=="AUS" | ccode=="CAN" | ccode=="DEU" | ccode=="JPN" | ccode=="USA"), fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe ln_mu if (ccode=="ARG" | ccode=="BRA" | ccode=="CHN" | ccode=="IND" | ccode=="KEN") | (ccode=="AUS" | ccode=="CAN" | ccode=="DEU" | ccode=="JPN" | ccode=="USA"), fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	


	* Estimate for each country separately
	foreach country in COL JPN {
		xtreg tar_savg_ahs estabsize femalework wagepe if ccode=="`country'", fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
		xtreg tar_savg_ahs estabsize femalework wagepe mu if ccode=="`country'", fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	

		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe if ccode=="`country'", fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
		xtreg ln_tar_savg_ahs ln_estabsize ln_femalework ln_wagepe ln_mu if ccode=="`country'", fe vce(robust)
		outreg2 using "Regression.txt", append bracket ctitle("Average Tariffs")	
	}

	graph drop _all


*	Erase construction files
	
	cd "$input/Chapter2/Datasets"

		foreach file in 	AverageTariff.dta TPPwithimppen.dta ImportPenetrationRate.dta Ratios.dta		{
	erase `file'
	}
	
	
	
exit
exit
exit
